### R code from vignette source 'BradleyTerry.Rnw'

###################################################
### code chunk number 1: CitationData
###################################################
library(BradleyTerry2)
data(citations)


###################################################
### code chunk number 2: CitationData2
###################################################
citations


###################################################
### code chunk number 3: countsToBinomial
###################################################
citations.sf <- countsToBinomial(citations)
names(citations.sf)[1:2] <- c("journal1", "journal2")
citations.sf


###################################################
### code chunk number 4: citeModel
###################################################
citeModel <- BTm(cbind(win1, win2), journal1, journal2, ~ journal, id = "journal", data = citations.sf)
citeModel


###################################################
### code chunk number 5: citeModelupdate
###################################################
update(citeModel, refcat = "JASA")


###################################################
### code chunk number 6: springall
###################################################
options(show.signif.stars = FALSE)
data(springall)
summary(springall.model <- BTm(cbind(win.adj, loss.adj), col, row,
                               ~ flav[..] + gel[..] +
                                 flav.2[..] + gel.2[..] + flav.gel[..] +
                                 (1 | ..),
                               data = springall))


###################################################
### code chunk number 7: baseball
###################################################
data(baseball)
head(baseball)


###################################################
### code chunk number 8: baseballModel
###################################################
data(baseball)
baseballModel1 <- BTm(cbind(home.wins, away.wins), home.team, away.team,
                      data = baseball, id = "team")
summary(baseballModel1)


###################################################
### code chunk number 9: baseballDataUpdate
###################################################
baseball$home.team <- data.frame(team = baseball$home.team, at.home = 1)
baseball$away.team <- data.frame(team = baseball$away.team, at.home = 0)


###################################################
### code chunk number 10: baseballModelupdate
###################################################
baseballModel2 <- update(baseballModel1, formula = ~ team + at.home)
summary(baseballModel2)


###################################################
### code chunk number 11: CEMSmodel
###################################################
data(CEMS)
table8.model <-  BTm(outcome = cbind(win1.adj, win2.adj),
                     player1 = school1, player2 = school2,
                     formula = ~ .. +
                         WOR[student] * LAT[..] +
                         DEG[student] * St.Gallen[..] +
                         STUD[student] * Paris[..] +
                         STUD[student] * St.Gallen[..] +
                         ENG[student] * St.Gallen[..] +
                         FRA[student] * London[..] +
                         FRA[student] * Paris[..] +
                         SPA[student] * Barcelona[..] +
                         ITA[student] * London[..] +
                         ITA[student] * Milano[..] +
                         SEX[student] * Milano[..],
                     refcat = "Stockholm",
                     data = CEMS)


###################################################
### code chunk number 12: BTabilities
###################################################
BTabilities(baseballModel2)


###################################################
### code chunk number 13: BTabilities2
###################################################
BTabilities(springall.model)


###################################################
### code chunk number 14: residuals
###################################################
res.pearson <- round(residuals(springall.model), 3)
head(cbind(springall$contests, res.pearson))


###################################################
### code chunk number 15: BTresiduals
###################################################
res <- residuals(springall.model, type = "grouped")
#  with(springall$predictors, plot(flav, res))
#  with(springall$predictors, plot(gel, res))


###################################################
### code chunk number 16: residualWLS
###################################################
lm(res ~ flav, weights = attr(res, "weights"), data = springall$predictors)
lm(res ~ gel, weights = attr(res, "weights"), data = springall$predictors)


###################################################
### code chunk number 17: functions
###################################################
## cf. prompt
for (fn in getNamespaceExports("BradleyTerry2")) {
    name <- as.name(fn)
    args <- formals(fn)
    n <- length(args)
    arg.names <- arg.n <- names(args)
    arg.n[arg.n == "..."] <- "\\dots"
    is.missing.arg <- function(arg) typeof(arg) == "symbol" &&
        deparse(arg) == ""
    Call <- paste(name, "(", sep = "")
        for (i in seq_len(n)) {
        Call <- paste(Call, arg.names[i], if (!is.missing.arg(args[[i]]))
            paste(" = ", paste(deparse(args[[i]]),
                collapse = "\n"), sep = ""), sep = "")
        if (i != n)
            Call <- paste(Call, ", ", sep = "")
    }
    Call <- paste(Call, ")", sep = "")
    cat(deparse(parse(text = Call)[[1]]), fill = TRUE)
}


